"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElectronDialogManagerMain = void 0;
var electron_1 = require("electron");
function showErrorBox(ev, title, content) {
    electron_1.dialog.showErrorBox(title, content);
}
function showCertificateTrustDialog(ev, id, options) {
    electron_1.dialog.showCertificateTrustDialog(options).then(function () {
        ev.sender.send('edm_showCertificateTrustDialog', id);
    });
}
function showMessageBox(ev, id, options) {
    electron_1.dialog.showMessageBox(options).then(function (result) {
        ev.sender.send('edm_showMessageBox', id, result);
    });
}
function showOpenDialog(ev, id, options) {
    electron_1.dialog.showOpenDialog(options).then(function (result) {
        ev.sender.send('edm_showOpenDialog', id, result);
    });
}
function showSaveDialog(ev, id, options) {
    electron_1.dialog.showSaveDialog(options).then(function (result) {
        ev.sender.send('edm_showSaveDialog', id, result);
    });
}
var activated = false;
function isMainProcess() {
    return (process && process.type === 'browser');
}
var ElectronDialogManagerMain = /** @class */ (function () {
    function ElectronDialogManagerMain() {
    }
    /**
     * Activate dialog manager in the main process
     * @returns return true if it has been activated
     */
    ElectronDialogManagerMain.activate = function () {
        if (isMainProcess() === false)
            throw new Error('ElectronDialogManagerMain can only be activated in the main process.');
        if (activated === true)
            return false;
        activated = true;
        electron_1.ipcMain.on('edm_showErrorBox', showErrorBox);
        electron_1.ipcMain.on('edm_showCertificateTrustDialog', showCertificateTrustDialog);
        electron_1.ipcMain.on('edm_showMessageBox', showMessageBox);
        electron_1.ipcMain.on('edm_showOpenDialog', showOpenDialog);
        electron_1.ipcMain.on('edm_showSaveDialog', showSaveDialog);
        return true;
    };
    /**
     * Deactivate dialog manager if needed
     * @returns return true if it has been deactivated
     */
    ElectronDialogManagerMain.deactivate = function () {
        if (isMainProcess() === false)
            throw new Error('ElectronDialogManagerMain can only be deactivated from the main process.');
        if (activated === false)
            return false;
        activated = false;
        electron_1.ipcMain.off('edm_showErrorBox', showErrorBox);
        electron_1.ipcMain.off('edm_showCertificateTrustDialog', showCertificateTrustDialog);
        electron_1.ipcMain.off('edm_showMessageBox', showMessageBox);
        electron_1.ipcMain.off('edm_showOpenDialog', showOpenDialog);
        electron_1.ipcMain.off('edm_showSaveDialog', showSaveDialog);
        return true;
    };
    return ElectronDialogManagerMain;
}());
exports.ElectronDialogManagerMain = ElectronDialogManagerMain;
